#!/usr/local/bin/ksh93 -p
#
# CDDL HEADER START
#
# The contents of this file are subject to the terms of the
# Common Development and Distribution License (the "License").
# You may not use this file except in compliance with the License.
#
# You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
# or http://www.opensolaris.org/os/licensing.
# See the License for the specific language governing permissions
# and limitations under the License.
#
# When distributing Covered Code, include this CDDL HEADER in each
# file and include the License file at usr/src/OPENSOLARIS.LICENSE.
# If applicable, add the following below this CDDL HEADER, with the
# fields enclosed by brackets "[]" replaced with your own identifying
# information: Portions Copyright [yyyy] [name of copyright owner]
#
# CDDL HEADER END
#

#
# Copyright 2012 Spectra Logic.  All rights reserved.
# Use is subject to license terms.
#
# ident	"@(#)hotspare_replace_004_pos.ksh	1.0	12/08/09 SL"
#
. $STF_SUITE/tests/functional/hotspare/hotspare.kshlib

################################################################################
#
# __stc_assertion_start
#
# ID: hotspare_replace_004_pos
#
# DESCRIPTION: 
#	If a vdev becomes degraded in a pool with a spare, the spare will be
#	activated.
#       
#
# STRATEGY:
#	1. Create 1 storage pools with hot spares.  Use files instead of disks,
#	   because it is much easier to cause checksum errors on a small file
#	   than on a large disk.
#	2. Fail one vdev in one pool to make 1 hotspare in use.
#	3. Verify that the spare is in use.
#
# TESTABILITY: explicit
#
# TEST_AUTOMATION_LEVEL: automated
#
# CODING STATUS: COMPLETED (2012-08-06)
#
# __stc_assertion_end
#
###############################################################################

verify_runnable "global"
verify_runtime $RT_LONG

function cleanup
{
	if poolexists $TESTPOOL ; then 
		destroy_pool $TESTPOOL
	fi

	partition_cleanup
}


log_onexit cleanup

function verify_assertion # type
{
	typeset err_dev=${devarray[3]}
	typeset mntp=$(get_prop mountpoint $TESTPOOL)
 
	# do some IO on the fs $TESTPOOL
	log_must $DD if=/dev/zero of=$mntp/$TESTFILE0 bs=512 count=2048

	# error out the $TESTPOOL to make sdev in use
	log_must $DD if=/dev/zero bs=1024k count=64 conv=notrunc of=$err_dev

	$SYNC
	log_must $ZPOOL scrub $TESTPOOL
	while is_pool_scrubbing $TESTPOOL ; do
		$SLEEP 2
	done

	# ZFSD can take up to 60 seconds to degrade an array in response to
	# errors (though it's usually faster).  
	for ((timeout=0; $timeout<10; timeout=$timeout+1)); do
		check_state $TESTPOOL "$sdev" "INUSE"
		spare_inuse=$?
		if [[ $spare_inuse == 0 ]]; then
			break
		fi
		$SLEEP 6
	done
	log_must $ZPOOL status $TESTPOOL
	log_must check_state $TESTPOOL "$sdev" "INUSE"

	# do cleanup
	destroy_pool $TESTPOOL
}

log_onexit cleanup

log_assert "If a vdev fails, the spare will be activated."

set_devs

typeset  sdev="${devarray[0]}"

set -A my_keywords "mirror" "raidz1" "raidz2"

for keyword in "${my_keywords[@]}"; do
        setup_hotspares "$keyword" "$sparedevs"
        verify_assertion "$keyword"
done
