#! /usr/local/bin/ksh93 -p
#
# CDDL HEADER START
#
# The contents of this file are subject to the terms of the
# Common Development and Distribution License (the "License").
# You may not use this file except in compliance with the License.
#
# You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
# or http://www.opensolaris.org/os/licensing.
# See the License for the specific language governing permissions
# and limitations under the License.
#
# When distributing Covered Code, include this CDDL HEADER in each
# file and include the License file at usr/src/OPENSOLARIS.LICENSE.
# If applicable, add the following below this CDDL HEADER, with the
# fields enclosed by brackets "[]" replaced with your own identifying
# information: Portions Copyright [yyyy] [name of copyright owner]
#
# CDDL HEADER END
#

# 
# Copyright 2007 Sun Microsystems, Inc.  All rights reserved.
# Use is subject to license terms.
# 
# ident	"@(#)smf_fmri_transition_state_test_01.ksh	1.3	07/04/12 SMI"
#

. ${STF_TOOLS}/contrib/include/libsmf.shlib

typeset -i myid=`/usr/bin/id -u`
if [ $myid -ne 0 ]; then
	print "This test must be run by root"
	print "Test Unresolved"
	exit 2
fi

fname=smf_fmri_transition_state

print "--INFO: Test the 'do' mode of the function '$fname'
	using the nfs/mapid service"

fmri="network/nfs/mapid:default"
timeout=5		# short 5 second timeout

print "--INFO: disable $fmri"

tstate="disabled"

print "--INFO: Invoke 'smf_fmri_transition_state \"do\" $fmri $tstate $timeout"
smf_fmri_transition_state "do" $fmri $tstate $timeout
if [ $? -ne 0 ]; then
	print "--DIAG: Could not transition FMRI '$fmri' to state '$tstate'
Test Failed"
	exit 1
fi

curstate="`smf_get_state $fmri`"
if [ "$curstate" != "$tstate" ]; then
	print "--DIAG: State transition failed
		EXPECTED: state of fmri '$fmri' is '$tstate'
		OBSERVED: state of fmri '$fmri' is '$curstate'
Test Failed"
	exit 1
fi

print "--INFO: enable $fmri"

tstate="online"

print "--INFO: Invoke 'smf_fmri_transition_state \"do\" $fmri $tstate $timeout"
smf_fmri_transition_state "do" $fmri $tstate $timeout
if [ $? -ne 0 ]; then
	print "--DIAG: Could not transition FMRI '$fmri' to state '$tstate'
Test Failed"
	exit 1
fi

curstate="`smf_get_state $fmri`"
if [ "$curstate" != "$tstate" ]; then
	print "--DIAG: State transition failed
		EXPECTED: state of fmri '$fmri' is '$tstate'
		OBSERVED: state of fmri '$fmri' is '$curstate'
Test Failed"
	exit 1
fi

print "--INFO: Put $fmri in maintenance state"

tstate="maintenance"

print "--INFO: Invoke 'smf_fmri_transition_state \"do\" $fmri $tstate $timeout'"
smf_fmri_transition_state "do" $fmri $tstate $timeout
if [ $? -ne 0 ]; then
	print "--DIAG: Could not transition FMRI '$fmri' to state '$tstate'
Test Failed"
	exit 1
fi

curstate="`smf_get_state $fmri`"
if [ "$curstate" != "$tstate" ]; then
	print "--DIAG: State transition failed
		EXPECTED: state of '$fmri' is '$tstate'
		OBSERVED: state of '$fmri' is '$curstate'
Test Failed"
	exit 1
fi

print "--INFO: Setup $fmri to be restarted"

tstate="restart"

# Note that 'restart' is not really a valid "state".
# It *is* a valid state transition.

print "--INFO: Invoke 'smf_fmri_transition_state \"do\" $fmri $tstate $timeout'"
smf_fmri_transition_state "do" $fmri $tstate $timeout
if [ $? -ne 0 ]; then
	print "--DIAG: Could not transition FMRI '$fmri' to state '$tstate'
Test Failed"
	exit 1
fi

# an fmri in maintenance continues to be in maintenance even after restart
curstate="`smf_get_state $fmri`"
if [ "$curstate" != "maintenance" ]; then
	print "--DIAG: State transition failed
		EXPECTED: state of '$fmri' is '$maintenance'
		OBSERVED: state of '$fmri' is '$curstate'
Test Failed"
	exit 1
fi

print "--INFO: Clear maintenance state"

tstate="clear"

# Note that 'clear' is not really a valid "state".
# It *is* a valid state transition.

print "--INFO: Invoke 'smf_fmri_transition_state \"do\" $fmri $tstate $timeout'"
smf_fmri_transition_state "do" $fmri $tstate $timeout
if [ $? -ne 0 ]; then
	print "--DIAG: Could not clear maintenance state on '$fmri'
Test Failed"
	exit 1
fi

# After 'clear',  the fmri should have been restarted and should be online
curstate="`smf_get_state $fmri`"
if [ "$curstate" != "online" ]; then
	print "--DIAG: State transition failed
		EXPECTED: state of '$fmri' is not 'maintenance'
		OBSERVED: state of '$fmri' is '$curstate'
Test Failed"
	exit 1
fi

print "Test Passed"
exit 0
